==> tdxtrader-0.2.1.tar.gz: tdxtrader-0.2.1/CHANGELOG.md <==
# CHANGELOG


## v0.2.1 (2024-12-01)

### Bug Fixes

- 解决非交易日时间戳不对导致撤单判断有问题
  ([`14ff6ed`](https://github.com/zsrl/tdxtrader/commit/14ff6ed36aee49f73767041ecc8187278cfeeec3))


## v0.2.0 (2024-11-28)

### Features

- 增加自动撤单功能
  ([`62602fe`](https://github.com/zsrl/tdxtrader/commit/62602fe5c59a0b9d7c577e312fb339da12ff334e))

### Performance Improvements

- 监听可撤单的委托
  ([`1c3ae87`](https://github.com/zsrl/tdxtrader/commit/1c3ae874824906fad6a7a353c879d95ca09c7337))


## v0.1.7 (2024-11-27)


## v0.1.6 (2024-11-27)

### Bug Fixes

- 修改没有持仓时卖出报错
  ([`174e690`](https://github.com/zsrl/tdxtrader/commit/174e69010a9b3c8912714452e431945ff819b13f))

### Performance Improvements

- 优化异常捕获，下单报错不影响程序运行
  ([`06fb844`](https://github.com/zsrl/tdxtrader/commit/06fb8449ea50d5a92158befe03a8afec43396c68))


## v0.1.5 (2024-11-27)

### Performance Improvements

- 优化时间输出格式
  ([`fab0845`](https://github.com/zsrl/tdxtrader/commit/fab0845c1b1556eab41f42d02d721f33cdc82034))


## v0.1.4 (2024-11-26)

### Bug Fixes

- 删除描述
  ([`99e0797`](https://github.com/zsrl/tdxtrader/commit/99e0797f1e3827e5266343df20c5265f78214894))

- 修改
  ([`818e27b`](https://github.com/zsrl/tdxtrader/commit/818e27b1ec45014201503210eeaa7c7b403d4f90))


## v0.1.3 (2024-11-26)

### Bug Fixes

- 增加配置
  ([`403b6c1`](https://github.com/zsrl/tdxtrader/commit/403b6c1ebeaa4bdd60490aeab29a1ee5330535b2))


## v0.1.2 (2024-11-26)

### Bug Fixes

- 增加描述
  ([`2129ef0`](https://github.com/zsrl/tdxtrader/commit/2129ef061731a9e281398427f6d0a92ea5efc920))


## v0.1.1 (2024-11-26)

### Bug Fixes

- 调整版本号定义
  ([`cb0397c`](https://github.com/zsrl/tdxtrader/commit/cb0397c29cc8a69f3a9219aab06d6f210a427330))

### Performance Improvements

- 更新文档
  ([`73e6206`](https://github.com/zsrl/tdxtrader/commit/73e62065e1423fe173d5d731069a160f7c9be9a8))


## v0.1.0 (2024-11-26)

### Bug Fixes

- 解决农产品等带空格的股票报错
  ([`2eaabb6`](https://github.com/zsrl/tdxtrader/commit/2eaabb6338d5031dc9354e8eb18196d315ce9c9f))

- 发布修改
  ([`c5c0009`](https://github.com/zsrl/tdxtrader/commit/c5c0009de9638c61ab5be8ade130c6bd95a29a48))

- 删除多余的代码
  ([`3b901df`](https://github.com/zsrl/tdxtrader/commit/3b901dfeefcc098a1117dd2d4ed24c52025db95f))

### Features

- 完成初版
  ([`b10f618`](https://github.com/zsrl/tdxtrader/commit/b10f618dad3eace3343276647c35e61e8d7beae2))

### Performance Improvements

- 增加github actions
  ([`0289f6f`](https://github.com/zsrl/tdxtrader/commit/0289f6f9cad40d138d852d85ac3cf36e376d87a5))

- 增加说明
  ([`6909721`](https://github.com/zsrl/tdxtrader/commit/690972115231a23d1091e47ee692de9977189082))

==> tdxtrader-0.3.2.tar.gz: tdxtrader-0.3.2/CHANGELOG.md <==
# CHANGELOG


## v0.3.2 (2024-12-03)

### Bug Fixes

- 图片打码
  ([`119d23d`](https://github.com/zsrl/tdxtrader/commit/119d23d3c1f8f62273b7148ef1802956a14319a7))


## v0.3.1 (2024-12-03)

### Performance Improvements

- 优化文档
  ([`980177d`](https://github.com/zsrl/tdxtrader/commit/980177d2aa4a411dba9cecd205610b086ad7081c))


## v0.3.0 (2024-12-03)

### Features

- 增加企业微信消息推送
  ([`4b5e3fb`](https://github.com/zsrl/tdxtrader/commit/4b5e3fbec16f7aa75692d7e04f6175c70913a349))

### Performance Improvements

- 优化日志
  ([`db14fc8`](https://github.com/zsrl/tdxtrader/commit/db14fc8596b9ac3972e0d01c034780e786f36b79))


## v0.2.2 (2024-12-03)

### Performance Improvements

- 优化测试
  ([`ffb1f3d`](https://github.com/zsrl/tdxtrader/commit/ffb1f3d66ef7d28de432408a8e3cff4d070c69be))

- 优化输出
  ([`ca26e4a`](https://github.com/zsrl/tdxtrader/commit/ca26e4a67d2d2d943711e227697492b9ec43240b))

- 增加按金额下单
  ([`e915b9f`](https://github.com/zsrl/tdxtrader/commit/e915b9fda4873551a61ec3490432794eae5cd470))


## v0.2.1 (2024-12-01)

### Bug Fixes

- 解决非交易日时间戳不对导致撤单判断有问题
  ([`14ff6ed`](https://github.com/zsrl/tdxtrader/commit/14ff6ed36aee49f73767041ecc8187278cfeeec3))


## v0.2.0 (2024-11-28)

### Features

- 增加自动撤单功能
  ([`62602fe`](https://github.com/zsrl/tdxtrader/commit/62602fe5c59a0b9d7c577e312fb339da12ff334e))

### Performance Improvements

- 监听可撤单的委托
  ([`1c3ae87`](https://github.com/zsrl/tdxtrader/commit/1c3ae874824906fad6a7a353c879d95ca09c7337))


## v0.1.7 (2024-11-27)


## v0.1.6 (2024-11-27)

### Bug Fixes

- 修改没有持仓时卖出报错
  ([`174e690`](https://github.com/zsrl/tdxtrader/commit/174e69010a9b3c8912714452e431945ff819b13f))

### Performance Improvements

- 优化异常捕获，下单报错不影响程序运行
  ([`06fb844`](https://github.com/zsrl/tdxtrader/commit/06fb8449ea50d5a92158befe03a8afec43396c68))


## v0.1.5 (2024-11-27)

### Performance Improvements

- 优化时间输出格式
  ([`fab0845`](https://github.com/zsrl/tdxtrader/commit/fab0845c1b1556eab41f42d02d721f33cdc82034))


## v0.1.4 (2024-11-26)

### Bug Fixes

- 修改
  ([`818e27b`](https://github.com/zsrl/tdxtrader/commit/818e27b1ec45014201503210eeaa7c7b403d4f90))

- 删除描述
  ([`99e0797`](https://github.com/zsrl/tdxtrader/commit/99e0797f1e3827e5266343df20c5265f78214894))


## v0.1.3 (2024-11-26)

### Bug Fixes

- 增加配置
  ([`403b6c1`](https://github.com/zsrl/tdxtrader/commit/403b6c1ebeaa4bdd60490aeab29a1ee5330535b2))


## v0.1.2 (2024-11-26)

### Bug Fixes

- 增加描述
  ([`2129ef0`](https://github.com/zsrl/tdxtrader/commit/2129ef061731a9e281398427f6d0a92ea5efc920))


## v0.1.1 (2024-11-26)

### Bug Fixes

- 调整版本号定义
  ([`cb0397c`](https://github.com/zsrl/tdxtrader/commit/cb0397c29cc8a69f3a9219aab06d6f210a427330))

### Performance Improvements

- 更新文档
  ([`73e6206`](https://github.com/zsrl/tdxtrader/commit/73e62065e1423fe173d5d731069a160f7c9be9a8))


## v0.1.0 (2024-11-26)

### Bug Fixes

- 删除多余的代码
  ([`3b901df`](https://github.com/zsrl/tdxtrader/commit/3b901dfeefcc098a1117dd2d4ed24c52025db95f))

- 发布修改
  ([`c5c0009`](https://github.com/zsrl/tdxtrader/commit/c5c0009de9638c61ab5be8ade130c6bd95a29a48))

- 解决农产品等带空格的股票报错
  ([`2eaabb6`](https://github.com/zsrl/tdxtrader/commit/2eaabb6338d5031dc9354e8eb18196d315ce9c9f))

### Features

- 完成初版
  ([`b10f618`](https://github.com/zsrl/tdxtrader/commit/b10f618dad3eace3343276647c35e61e8d7beae2))

### Performance Improvements

- 增加github actions
  ([`0289f6f`](https://github.com/zsrl/tdxtrader/commit/0289f6f9cad40d138d852d85ac3cf36e376d87a5))

- 增加说明
  ([`6909721`](https://github.com/zsrl/tdxtrader/commit/690972115231a23d1091e47ee692de9977189082))
